com.phronemophobic.clj-media.gif

write-gif!

(write-gif! media fname)(write-gif! media fname {:keys [dither transparent? max-colors alpha-threshold], :as opts})

Write a gif to fname with contents of media.

media can be any valid media.

Available options: :dither A dithering algorithm. One of "bayer", "heckbert", "floyd_steinberg", "sierra2", "sierra2_4a", "sierra3", "burkes", "atkinson", "none". See avfilter/paletteuse for more info. default "sierra2_4a". :transparent? Allow transparency. default: true. :max-colors Set the maximum number of colors to use in the palette. default 256. :alpha-threshold Alpha cutoff for transparency. default 128.